#include "U8glib.h"
#include <Wire.h>
#include <Rtc_Pcf8563.h>

Rtc_Pcf8563 rtc;//初始化实时时钟

#define pin 5  //定义中断led显示引脚

volatile int alarm_flag=0;//定义alarm（）函数使能数据

U8GLIB_SSD1306_128X64 u8g(U8G_I2C_OPT_NONE);	//配置OLED显示屏
// HW SPI Com: CS = 10, A0 = 9 (Hardware Pins are  SCK = 13 and MOSI = 11)

//定义microduino图标大小
#define u8g_logo_width 128
#define u8g_logo_height 18

const unsigned char u8g_logo_bits[] U8G_PROGMEM = {
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x01,0xE0,
  0x03,0x00,0x00,0x00,0x00,0x7E,0x00,0xF0,0x01,0x00,0x00,0x00,
  0x00,0xFE,0xF9,0xF7,0x07,0x00,0x00,0x00,0x00,0x3C,0x00,0xF8,
  0x03,0x00,0x00,0x00,0x00,0xFC,0xF9,0xE1,0x03,0x00,0x00,0x00,
  0x00,0x38,0x00,0xF0,0x01,0x00,0x00,0x00,0x00,0xFC,0xFF,0x01,
  0x00,0x00,0x00,0x00,0x00,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
  0x00,0xFC,0xEF,0xF9,0x8F,0xD7,0x73,0xF1,0xC1,0x3B,0x9F,0xFF,
  0xFF,0x1E,0x3E,0x00,0x00,0xBC,0xEF,0xC1,0xE1,0x9F,0xFF,0xDD,
  0xE3,0x3F,0xCC,0xE1,0xF0,0xBF,0x7B,0x00,0x00,0x3C,0xF7,0xE1,
  0xE1,0x9F,0xFF,0xC6,0xF7,0x3E,0x8E,0xF3,0xF0,0xFF,0xF8,0x00,
  0x00,0x3C,0xF3,0xE1,0xF1,0x93,0xFF,0xE6,0xF7,0x3C,0x8F,0xF7,
  0xF0,0xFF,0xFC,0x00,0x00,0x7C,0xF2,0xE1,0xF1,0x83,0x87,0xFE,
  0xF7,0x39,0xFF,0xF7,0xF0,0xFF,0xFF,0x00,0x00,0x7C,0xF0,0xE3,
  0xF3,0xA3,0x03,0xFE,0xF7,0x3F,0xFF,0xF7,0x71,0xFC,0xFF,0x00,
  0x00,0x7C,0xF8,0xE3,0xF3,0xBF,0x03,0xFE,0xE3,0x3F,0xFF,0xF3,
  0x71,0xDC,0x7F,0x00,0x00,0x7E,0xFC,0xE7,0xE3,0xBF,0x03,0xFC,
  0xE3,0x3F,0xFE,0xF3,0x71,0x9C,0x7F,0x00,0x00,0xC1,0x03,0xF8,
  0xCF,0xE7,0x0F,0xF0,0x00,0x7F,0xFC,0xFC,0xFF,0x3E,0x1E,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};//microduino图标

void setup()
{
  pinMode(2, INPUT);   //配置中断输入引脚
  pinMode(pin, OUTPUT); //配置中断led引脚

  volcdsetup("  Welcome! ",20,32);//开机显示
  delay(500);

  volcdsetup("Load Time...",20,32);
  delay(1000);
  vosettime();

  volcdsetup("Load Alarm..",20,32);
  delay(1000);
  //报警引脚变为低电平，当发生匹配，这触发了中断服务程序
  //setAlarm(min, hr, day, weekday )，99表示该值可以不用匹配
  rtc.clearAlarm();   
  rtc.setAlarm(29, 99, 99, 99);//闹铃时间
  attachInterrupt(0, blink, FALLING);//中断检测
  volcdlogo(0,20);
  delay(1000);
}

void loop()
{
  if (alarm_flag==1)//判断是否中断
  {
    clr_alarm();
  }
  //界面显示
  u8g.firstPage();
  do
  {
    draw();
  }
  while( u8g.nextPage() );
}
//=======================屏幕显示函数===========================//
void draw(void)
{
  //调用时间，不能缺少
  rtc.formatDate();
  rtc.formatTime();

  u8g.setFont( u8g_font_fub14);//字体大小

  u8g.setPrintPos(20, 30); //字体坐标
  u8g.print(rtc.getHour());
  u8g.print(":");
  u8g.print(rtc.getMinute());
  u8g.print(":");
  u8g.print(rtc.getSecond());

  u8g.setFont(u8g_font_chikitar);//字体大小
  u8g.drawFrame(0, 54,128,10);//画矩形框（起点坐标（x,y）,long,high）
  u8g.setPrintPos(3, 62); //字体坐标 
  u8g.print("Microduino-RTC v1.0  201310");
}

//=======================microduino图标显示函数===========================//
void volcdlogo(unsigned int x,unsigned int y)
{
  u8g.firstPage();  
  do {
    u8g.drawXBMP( x, y, u8g_logo_width, u8g_logo_height, u8g_logo_bits);
  } 
  while( u8g.nextPage() );
}
//=======================开机状态显示函数===========================//
void volcdsetup(char* zi,int x,int y)
{
  u8g.firstPage();  
  do {
    u8g.setFont(u8g_font_9x18Br);
    u8g.setPrintPos(x, y); 
    u8g.print(zi);
  } 
  while( u8g.nextPage() );
}

//=======================初始化时间函数===========================//
void vosettime()
{
  //rtc.initClock();
  //day, weekday, month, century(1=1900, 0=2000), year(0-99)
  rtc.setDate(16, 1, 12, 0, 13);
  //hr, min, sec
  rtc.setTime(15, 28, 50);
}

//=======================报警函数===========================//
void clr_alarm()
{
  rtc.clearAlarm();   
  detachInterrupt(0);
  alarm_flag=0;
  attachInterrupt(0, blink, FALLING);
  //屏幕显示倒计时
  for(int i=0;i<61;i++){
    u8g.firstPage();  
    do {
      u8g.setFont( u8g_font_fub25);
      u8g.setPrintPos(50, 44); 
      if(i>50)
      {
        u8g.print("0"); 
        u8g.print(60-i);
      }
      else
        u8g.print(60-i);
    } 
    while( u8g.nextPage() );
    //led显示
    digitalWrite(5, HIGH); 
    delay(500);
    digitalWrite(5, LOW); 
    delay(500);
  }
}
//=======================中断服务函数===========================//
void blink()
{
  alarm_flag=1;
}




